#ifndef POKEPLATINUM_UNK_0205DAC8_H
#define POKEPLATINUM_UNK_0205DAC8_H

BOOL sub_0205DAC8(u8 param0);
BOOL sub_0205DAD4(u8 param0);
BOOL sub_0205DAE0(u8 param0);
BOOL sub_0205DAEC(u8 param0);
BOOL sub_0205DAF8(u8 param0);
BOOL sub_0205DB04(u8 param0);
BOOL sub_0205DB10(u8 param0);
BOOL sub_0205DB1C(u8 param0);
BOOL sub_0205DB28(u8 param0);
BOOL sub_0205DB34(u8 param0);
BOOL sub_0205DB40(u8 param0);
BOOL sub_0205DB4C(u8 param0);
BOOL sub_0205DB58(u8 param0);
BOOL sub_0205DB6C(u8 param0);
BOOL sub_0205DB78(u8 param0);
BOOL sub_0205DB84(u8 param0);
BOOL sub_0205DB90(u8 param0);
BOOL sub_0205DB9C(u8 param0);
BOOL sub_0205DBA8(u8 param0);
BOOL sub_0205DBB4(u8 param0);
BOOL sub_0205DBC0(u8 param0);
BOOL sub_0205DBCC(u8 param0);
BOOL sub_0205DBD8(u8 param0);
BOOL sub_0205DBE4(u8 param0);
BOOL sub_0205DBF0(u8 param0);
BOOL sub_0205DBFC(u8 param0);
BOOL sub_0205DC08(u8 param0);
BOOL sub_0205DC14(u8 param0);
BOOL sub_0205DC20(u8 param0);
BOOL sub_0205DC2C(u8 param0);
BOOL sub_0205DC38(u8 param0);
BOOL sub_0205DC44(u8 param0);
BOOL sub_0205DC50(u8 param0);
BOOL sub_0205DC5C(u8 param0);
BOOL sub_0205DC68(u8 param0);
BOOL sub_0205DC74(u8 param0);
BOOL sub_0205DC80(u8 param0);
BOOL sub_0205DC8C(u8 param0);
BOOL sub_0205DC98(u8 param0);
BOOL sub_0205DCA4(u8 param0);
BOOL sub_0205DCB0(u8 param0);
BOOL sub_0205DCBC(u8 param0);
BOOL sub_0205DCC8(u8 param0);
BOOL sub_0205DCD4(u8 param0);
BOOL sub_0205DCE0(u8 param0);
BOOL sub_0205DCF0(u8 param0);
BOOL sub_0205DCFC(u8 param0);
BOOL sub_0205DD0C(u8 param0);
BOOL sub_0205DD18(u8 param0);
BOOL sub_0205DD38(u8 param0);
BOOL sub_0205DD44(u8 param0);
BOOL sub_0205DD50(u8 param0);
BOOL sub_0205DD5C(u8 param0);
BOOL sub_0205DD68(u8 param0);
BOOL sub_0205DD78(u8 param0);
BOOL sub_0205DD84(u8 param0);
BOOL sub_0205DD90(u8 param0);
BOOL sub_0205DD9C(u8 param0);
BOOL sub_0205DDA8(u8 param0);
BOOL sub_0205DDB4(u8 param0);
BOOL sub_0205DDC0(u8 param0);
BOOL sub_0205DDCC(u8 param0);
BOOL sub_0205DDF0(u8 param0);
BOOL sub_0205DE14(u8 param0);
BOOL sub_0205DE38(u8 param0);
BOOL sub_0205DE5C(u8 param0);
BOOL sub_0205DE6C(u8 param0);
BOOL sub_0205DE84(u8 param0);
BOOL sub_0205DE90(u8 param0);
BOOL sub_0205DEB4(u8 param0);
BOOL sub_0205DEC0(u8 param0);
BOOL sub_0205DECC(u8 param0);
BOOL sub_0205DED8(u8 param0);
BOOL sub_0205DEE4(u8 param0);
BOOL sub_0205DEF0(u8 param0);
BOOL sub_0205DEFC(u8 param0);
BOOL sub_0205DF10(u8 param0);
BOOL sub_0205DF34(u8 param0);
BOOL sub_0205DF58(u8 param0);
BOOL sub_0205DF64(u8 param0);
BOOL sub_0205DF78(u8 param0);
BOOL sub_0205DF8C(u8 param0);
u8 sub_0205DF98(void);
BOOL sub_0205DF9C(u8 param0);
BOOL sub_0205DFAC(u8 param0);
BOOL sub_0205DFB8(u8 param0);

#endif // POKEPLATINUM_UNK_0205DAC8_H
